AdseyeInitConfig class

初始化配置类

Constructors

AdseyeInitConfig({String? pangleAppId, String? tradPlusAppId, String? toponAppId, String? toponAppKey})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
pangleAppId String?
Pangle App ID
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toponAppId String?
TopOn App ID (预留参数,暂未使用)
final
toponAppKey String?
TopOn App Key (预留参数,暂未使用)
final
tradPlusAppId String?
TradPlus App ID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
转换为传递给原生端的参数 Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited