AdseyeInitListener class

初始化回调接口

Constructors

AdseyeInitListener({required void onInitSuccess(), required void onPreInitSuccess(), required void onInitFailed(String errorMsg)})

Properties

hashCode int
The hash code for this object.
no setterinherited
onInitFailed → void Function(String errorMsg)
final
onInitSuccess → void Function()
final
onPreInitSuccess → void Function()
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited