AdseyeLogger class

全局调试日志系统 提供统一的日志记录功能,支持不同级别的日志输出

Constructors

AdseyeLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

debug(String message) → void
输出调试信息 仅在调试模式下输出
error(String message) → void
输出错误信息 错误日志始终输出,即使在生产环境中
errorWithException(String message, [dynamic error, StackTrace? stackTrace]) → void
输出错误信息,包含异常对象 错误日志始终输出,即使在生产环境中
info(String message) → void
输出信息日志 仅在调试模式下输出
warning(String message) → void
输出警告信息 仅在调试模式下输出