NativeAd class

Properties

adUnitId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
loadListener AdseyeLoadListener?
getter/setter pairinherited
onDestroy Stream<void>
no setter
requestId String
finalinherited
revenueListener AdRevenueListener?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bindViewChannel(MethodChannel channel) → void
内部方法 由 AdseyeNativeAdViewContainer 调用,用于绑定视图通道
checkAdShowSuggestion() Future<bool>
inherited
destroy() → void
dispose() → void
inherited
isReady() Future<bool>
inherited
load({required AdseyeLoadListener listener}) Future<void>
加载原生广告数据
loadAd(String methodName, {required AdseyeLoadListener listener}) Future<void>
加载广告的通用逻辑
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processCallback(String methodName, Map<String, dynamic> args) → void
setDisplayListener(NativeAdDisplayListener listener) → void
设置展示回调监听器
showAd(String methodName, dynamic placementId) Future<void>
展示广告的通用逻辑
inherited
toString() String
A string representation of this object.
inherited
watchAdRevenue({required AdRevenueListener listener}) Future<void>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(String adUnitId) NativeAd
创建一个新的 NativeAd 实例