NativeAdDisplayListener class abstract

Constructors

NativeAdDisplayListener()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAdClicked() → void
广告被点击
onAdDisplayFailed(String errorMsg) → void
广告展示失败
onAdShow() → void
广告展示/曝光
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited