SplashAd class

单次开屏广告对象

Properties

adUnitId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
loadListener AdseyeLoadListener?
getter/setter pairinherited
requestId String
finalinherited
revenueListener AdRevenueListener?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAdShowSuggestion() Future<bool>
inherited
destroy() → void
inherited
dispose() → void
inherited
isReady() Future<bool>
inherited
load({required AdseyeLoadListener listener}) Future<void>
加载广告
loadAd(String methodName, {required AdseyeLoadListener listener}) Future<void>
加载广告的通用逻辑
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processCallback(String methodName, Map<String, dynamic> args) → void
show({required SplashDisplayListener listener, String? placementId}) Future<void>
展示广告
showAd(String methodName, dynamic placementId) Future<void>
展示广告的通用逻辑
inherited
toString() String
A string representation of this object.
inherited
watchAdRevenue({required AdRevenueListener listener}) Future<void>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(String adUnitId) SplashAd
创建并返回一个新的 SplashAd 实例