SplashDisplayListener class
只负责「展示」阶段的回调
Constructors
- SplashDisplayListener({required AdShow onAdShow, required AdClicked onAdClicked, required AdDismissed onAdDismiss, required AdShowFailed onAdDisplayFailed})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onAdClicked → void Function()
-
final
- onAdDismiss → void Function()
-
final
- onAdDisplayFailed → void Function()
-
final
- onAdShow → void Function()
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited