AdseyeAdPlugin class
广告插件对外 Dart API
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instanceChannel → MethodChannel
-
no setter
Static Methods
-
initialize(
AdseyeInitConfig config, {AdseyeInitListener? listener}) → Future< void> -
初始化广告 SDK
config初始化配置,包含所有必要的参数listener初始化监听器,可选参数 -
initializeWithParams(
{String? pangleAppId, String? tradPlusAppId, String? toponAppId, String? toponAppKey, AdseyeInitListener? listener}) → Future< void> - @deprecated 使用 initialize(AdseyeInitConfig config) 方法替代 保留此方法以保证向后兼容性
-
openDebugger(
) → Future< void> -
setMediaUserId(
{required String mediaUserId}) → Future< void>