AdseyeLoadListener class
只负责「加载」阶段的回调
Constructors
- AdseyeLoadListener({required AdLoadSuccess onAdLoaded, required AdLoadFailed onAdLoadFailed})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onAdLoaded → void Function()
-
final
- onAdLoadFailed → void Function(String errorMsg)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited