RewardedDisplayListener class
激励视频广告展示阶段回调
Constructors
- RewardedDisplayListener({required RewardedDisplayed onAdDisplayed, required RewardedClicked onAdClicked, required RewardedRewarded onAdRewarded, required RewardedDismissed onAdDismissed, required RewardedDVideoCompleted onAdVideoCompleted, required RewardedVideoStart onAdVideoStart, required RewardedDisplayFailed onAdDisplayFailed})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onAdClicked → void Function()
-
final
- onAdDismissed → void Function()
-
final
- onAdDisplayed → void Function()
-
final
- onAdDisplayFailed → void Function()
-
final
- onAdRewarded → void Function()
-
final
- onAdVideoCompleted → void Function()
-
final
- onAdVideoStart → void Function()
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited